bonobo-activation patch ...



Hi there,

	It'd be great to get this in - it's on the critical path.

	Regards,

		Michael.

Index: configure.in
===================================================================
RCS file: /cvs/gnome/gconf/configure.in,v
retrieving revision 1.82
diff -u -r1.82 configure.in
--- configure.in	2001/07/18 08:02:35	1.82
+++ configure.in	2001/08/01 16:02:41
@@ -120,7 +120,7 @@
         AC_FYI("Only building documentation")
 else
 
-PKGCONFIG_MODULES='gmodule-2.0 >= 1.3.5 gobject-2.0 >= 1.3.5 oaf-2.0'
+PKGCONFIG_MODULES='gmodule-2.0 >= 1.3.5 gobject-2.0 >= 1.3.5 bonobo-activation-2.0'
 PKGCONFIG_MODULES_WITH_XML="$PKGCONFIG_MODULES libxml-2.0"
 PKGCONFIG_MODULES_WITH_GTK="gtk+-2.0 $PKGCONFIG_MODULES"
 
Index: gconf-2.0.pc.in
===================================================================
RCS file: /cvs/gnome/gconf/gconf-2.0.pc.in,v
retrieving revision 1.1
diff -u -r1.1 gconf-2.0.pc.in
--- gconf-2.0.pc.in	2001/03/23 11:12:38	1.1
+++ gconf-2.0.pc.in	2001/08/01 16:02:41
@@ -7,6 +7,6 @@
 Name: gconf
 Description: GNOME Config System.
 Version: @VERSION@
-Requires: oaf-2.0
+Requires: bonobo-activation-2.0
 Libs: -L${libdir} -lgconf- MAJOR_VERSION@
 Cflags: -I${includedir}/gconf/@MAJOR_VERSION@
Index: gconf/gconf-database.c
===================================================================
RCS file: /cvs/gnome/gconf/gconf/gconf-database.c,v
retrieving revision 1.20
diff -u -r1.20 gconf-database.c
--- gconf/gconf-database.c	2001/07/24 03:05:14	1.20
+++ gconf/gconf-database.c	2001/08/01 16:02:42
@@ -23,7 +23,7 @@
 #include "gconf-locale.h"
 #include "gconfd.h"
 #include <unistd.h>
-#include <liboaf/liboaf.h>
+#include <bonobo-activation/bonobo-activation.h>
 #include <time.h>
 #include <stdlib.h>
 
@@ -1518,7 +1518,7 @@
   g_free (s);
   g_string_append_c (fd->str, ' ');
   
-  orb = oaf_orb_get ();
+  orb = bonobo_activation_orb_get ();
 
   CORBA_exception_init (&ev);
   
Index: gconf/gconf-internals.c
===================================================================
RCS file: /cvs/gnome/gconf/gconf/gconf-internals.c,v
retrieving revision 1.88
diff -u -r1.88 gconf-internals.c
--- gconf/gconf-internals.c	2001/07/22 18:37:58	1.88
+++ gconf/gconf-internals.c	2001/08/01 16:02:42
@@ -22,8 +22,7 @@
 #include "gconf-internals.h"
 #include "gconf-backend.h"
 #include "gconf-schema.h"
-#include <orbit/orbit.h>
-#include <liboaf/liboaf.h>
+#include <bonobo-activation/bonobo-activation.h>
 #include <string.h>
 #include <sys/stat.h>
 #include <sys/types.h>
@@ -438,7 +437,8 @@
   
   CORBA_exception_init (&ev);
 
-  ior = CORBA_ORB_object_to_string (oaf_orb_get (), obj, &ev);
+  ior = CORBA_ORB_object_to_string (
+	  bonobo_activation_orb_get (), obj, &ev);
 
   if (ior == NULL)
     {
@@ -2137,28 +2137,28 @@
       {
         const gchar* id = CORBA_exception_id(ev);
 
-        if (strcmp(id, "IDL:OAF/GeneralError:1.0") == 0)
+        if (strcmp(id, "IDL:Bonobo/GeneralError:1.0") == 0)
           {
-            OAF_GeneralError* ge = CORBA_exception_value(ev);
+            Bonobo_GeneralError* ge = CORBA_exception_value(ev);
 
             if (err)
               *err = gconf_error_new (GCONF_ERROR_OAF_ERROR,
-                                      _("OAF problem description: '%s'"),
+                                      _("bonobo-activation problem description: '%s'"),
                                       ge->description);
           }
-        else if (strcmp (id,"IDL:OAF/ActivationContext/NotListed:1.0" ) == 0)
+        else if (strcmp (id,"IDL:Bonobo/ActivationContext/NotListed:1.0" ) == 0)
           {
             if (err)
               *err = gconf_error_new(GCONF_ERROR_OAF_ERROR, _("attempt to remove not-listed OAF object directory"));
           }
-        else if (strcmp (id,"IDL:OAF/ActivationContext/AlreadyListed:1.0" ) == 0)
+        else if (strcmp (id,"IDL:Bonobo/ActivationContext/AlreadyListed:1.0" ) == 0)
           {
             if (err)
               *err = gconf_error_new(GCONF_ERROR_OAF_ERROR, _("attempt to add already-listed OAF directory")); 
           }
-        else if (strcmp (id,"IDL:OAF/ActivationContext/ParseFailed:1.0") == 0)
+        else if (strcmp (id,"IDL:Bonobo/ActivationContext/ParseFailed:1.0") == 0)
           {
-            OAF_ActivationContext_ParseFailed* pe = CORBA_exception_value(ev);
+            Bonobo_ActivationContext_ParseFailed* pe = CORBA_exception_value(ev);
             
             if (err)
               *err = gconf_error_new(GCONF_ERROR_OAF_ERROR, _("OAF parse error: %s"), pe->description);
@@ -2307,7 +2307,7 @@
 
                   CORBA_exception_init(&ev);
                   
-                  orb = oaf_orb_get();
+                  orb = bonobo_activation_orb_get();
 
                   if (orb == NULL)
                     {
Index: gconf/gconf-sources.c
===================================================================
RCS file: /cvs/gnome/gconf/gconf/gconf-sources.c,v
retrieving revision 1.34
diff -u -r1.34 gconf-sources.c
--- gconf/gconf-sources.c	2001/07/22 18:37:58	1.34
+++ gconf/gconf-sources.c	2001/08/01 16:02:42
@@ -605,7 +605,7 @@
   g_set_error (err,
                GCONF_ERROR,
                GCONF_ERROR_NO_WRITABLE_DATABASE,
-               _("Unable to store a value at key '%s', as the configuration server has no writeable databases. There are two common causes of this problem: 1) your configuration path file doesn't contain any databases or wasn't found or 2) OAF mistakenly created two gconfd processes. If you have two gconfd processes (or had two at the time the second was launched), then it's an OAF bug, not a GConf issue. Logging out, killing oafd and gconfd, and logging back in may help. As always, check the user.* syslog for details on problems gconfd encountered."),
+               _("Unable to store a value at key '%s', as the configuration server has no writeable databases. There are two common causes of this problem: 1) your configuration path file doesn't contain any databases or wasn't found or 2) bonobo-activation mistakenly created two gconfd processes. If you have two gconfd processes (or had two at the time the second was launched), then it's an bonobo-activation bug, not a GConf issue. Logging out, killing bonobo-activation-server and gconfd, and logging back in may help. As always, check the user.* syslog for details on problems gconfd encountered."),
                key);
 }
 
Index: gconf/gconf.c
===================================================================
RCS file: /cvs/gnome/gconf/gconf/gconf.c,v
retrieving revision 1.118
diff -u -r1.118 gconf.c
--- gconf/gconf.c	2001/07/24 03:05:14	1.118
+++ gconf/gconf.c	2001/08/01 16:02:43
@@ -32,7 +32,7 @@
 #include <sys/wait.h>
 #include <sys/time.h>
 #include <unistd.h>
-#include <liboaf/liboaf.h>
+#include <bonobo-activation/bonobo-activation.h>
 
 /* Returns TRUE if there was an error, frees exception, sets err */
 static gboolean gconf_handle_corba_exception(CORBA_Environment* ev, GError** err);
@@ -1845,15 +1845,15 @@
 try_to_contact_server(gboolean start_if_not_found, GError** err)
 {
   CORBA_Environment ev;
-  OAF_ActivationFlags flags;
+  Bonobo_ActivationFlags flags;
   
   CORBA_exception_init(&ev);
 
   flags = 0;
   if (!start_if_not_found)
-    flags |= OAF_FLAG_EXISTING_ONLY;
+    flags |= Bonobo_ACTIVATION_FLAG_EXISTING_ONLY;
   
-  server = oaf_activate_from_id ("OAFAID:["IID"]", flags, NULL, &ev);
+  server = bonobo_activation_activate_from_id ("OAFAID:["IID"]", flags, NULL, &ev);
 
   /* So try to ping server, by adding ourselves as a client */
   if (!CORBA_Object_is_nil (server, &ev))
@@ -1884,7 +1884,7 @@
 
       if (err && *err == NULL)
         *err = gconf_error_new(GCONF_ERROR_NO_SERVER,
-                               _("Error contacting configuration server: OAF returned nil from oaf_activate_from_id() and did not set an exception explaining the problem. This is a bug in the OAF package; something went wrong in OAF, and no error was reported. This is not a bug in the GConf package. Do not report a GConf bug unless you have information indicating what went wrong with OAF that was caused by GConf."));
+                               _("Error contacting configuration server: bonobo-activation returned nil from bonobo_activation_activate_from_id() and did not set an exception explaining the problem. This is a bug in the bonobo-activation package; something went wrong in bonobo-activation, and no error was reported. This is not a bug in the GConf package. Do not report a GConf bug unless you have information indicating what went wrong with bonobo-activation that was caused by GConf."));
     }
 
 #ifdef GCONF_ENABLE_DEBUG      
@@ -2137,7 +2137,8 @@
       
       g_assert (ev._major == CORBA_NO_EXCEPTION);
 
-      poa = (PortableServer_POA)CORBA_ORB_resolve_initial_references(oaf_orb_get(), "RootPOA", &ev);
+      poa = (PortableServer_POA)CORBA_ORB_resolve_initial_references(
+	      bonobo_activation_orb_get(), "RootPOA", &ev);
 
       g_assert (ev._major == CORBA_NO_EXCEPTION);
 
@@ -2179,13 +2180,13 @@
 
   gconf_preinit(NULL, NULL);
 
-  if (!oaf_is_initialized())
+  if (!bonobo_activation_is_initialized())
     {
-      orb = oaf_init(argc, argv);
+      orb = bonobo_activation_init(argc, argv);
     }
   else
     {
-      orb = oaf_orb_get();
+      orb = bonobo_activation_orb_get();
     }
       
   gconf_postinit(NULL, NULL);
Index: gconf/gconfd.c
===================================================================
RCS file: /cvs/gnome/gconf/gconf/gconfd.c,v
retrieving revision 1.104
diff -u -r1.104 gconfd.c
--- gconf/gconfd.c	2001/07/24 03:05:14	1.104
+++ gconf/gconfd.c	2001/08/01 16:02:43
@@ -51,7 +51,7 @@
 #include <ctype.h>
 #include <syslog.h>
 #include <time.h>
-#include <liboaf/liboaf.h>
+#include <bonobo-activation/bonobo-activation.h>
 
 /* This makes hash table safer when debugging */
 #ifndef GCONF_ENABLE_DEBUG
@@ -290,7 +290,7 @@
       /* Try using the default address xml:readwrite:$(HOME)/.gconf */
       addresses = g_slist_append(addresses, g_strconcat("xml:readwrite:", g_get_home_dir(), "/.gconf", NULL));
 
-      gconf_log(GCL_INFO, _("No configuration files found, trying to use the default config source `%s'"), addresses[0]);
+      gconf_log(GCL_INFO, _("No configuration files found, trying to use the default config source `%s'"), (char *)addresses->data);
     }
   
   if (addresses == NULL)
@@ -469,7 +469,7 @@
   const gchar* username;
   guint len;
   gchar* ior;
-  OAF_RegistrationResult result;
+  Bonobo_RegistrationResult result;
   int exit_code = 0;
   GError *err;
   char *lock_dir;
@@ -528,15 +528,15 @@
 
   CORBA_exception_init(&ev);
 
-  if (!oaf_init(argc, argv))
+  if (!bonobo_activation_init(argc, argv))
     {
-      gconf_log(GCL_ERR, _("Failed to init Object Activation Framework: please mail bug report to OAF maintainers"));
+      gconf_log(GCL_ERR, _("Failed to init Object Activation Framework: please mail bug report to bonobo-activation maintainers"));
       exit(1);
     }
 
   init_databases ();
 
-  orb = oaf_orb_get();
+  orb = bonobo_activation_orb_get();
   
   POA_ConfigServer__init(&poa_server_servant, &ev);
   
@@ -575,8 +575,8 @@
     {
       g_assert (err);
       
       /* Bad hack alert - register the current lockholder with oafd,
        * since oafd seems to have forgotten about us.
        */
       gconf_log (GCL_WARNING, _("Failed to get lock for daemon: %s"),
                  err->message);
@@ -584,23 +584,23 @@
 
       if (other_server != CORBA_OBJECT_NIL)
         {
-          gconf_log (GCL_WARNING, _("Registering existing server with oafd, since OAF appears to have leaked it"));
+          gconf_log (GCL_WARNING, _("Registering existing server with bonobo-activation-server, since we seem to have been leaked"));
           
-          result = oaf_active_server_register (IID, other_server);
+          result = bonobo_activation_active_server_register (IID, other_server);
           
-          if (result != OAF_REG_SUCCESS)
+          if (result != Bonobo_ACTIVATION_REG_SUCCESS)
             {
               switch (result)
                 {
-                case OAF_REG_NOT_LISTED:
+                case Bonobo_ACTIVATION_REG_NOT_LISTED:
                   gconf_log(GCL_ERR, _("OAF doesn't know about our IID; indicates broken installation; can't register existing server."));
                   break;
                   
-                case OAF_REG_ALREADY_ACTIVE:
+                case Bonobo_ACTIVATION_REG_ALREADY_ACTIVE:
                   gconf_log(GCL_ERR, _("Another gconfd already registered with OAF, so we can't register the existing server"));
                   break;
                   
-                case OAF_REG_ERROR:
+                case Bonobo_ACTIVATION_REG_ERROR:
                 default:
                   gconf_log(GCL_ERR, _("Unknown error registering existing gconfd with OAF; exiting"));
                   break;
@@ -622,23 +622,23 @@
      after setting up the POA etc. */
   gconf_server_load_sources();
   
-  result = oaf_active_server_register(IID, server);
+  result = bonobo_activation_active_server_register(IID, server);
 
-  if (result != OAF_REG_SUCCESS)
+  if (result != Bonobo_ACTIVATION_REG_SUCCESS)
     {
       switch (result)
         {
-        case OAF_REG_NOT_LISTED:
-          gconf_log(GCL_ERR, _("OAF doesn't know about our IID; indicates broken installation; can't register; exiting\n"));
+        case Bonobo_ACTIVATION_REG_NOT_LISTED:
+          gconf_log(GCL_ERR, _("bonobo-activation doesn't know about our IID; indicates broken installation; can't register; exiting\n"));
           break;
           
-        case OAF_REG_ALREADY_ACTIVE:
-          gconf_log(GCL_ERR, _("Another gconfd already registered with OAF; exiting\n"));
+        case Bonobo_ACTIVATION_REG_ALREADY_ACTIVE:
+          gconf_log(GCL_ERR, _("Another gconfd already registered with bonobo-activation; exiting\n"));
           break;
 
-        case OAF_REG_ERROR:
+        case Bonobo_ACTIVATION_REG_ERROR:
         default:
-          gconf_log(GCL_ERR, _("Unknown error registering gconfd with OAF; exiting\n"));
+          gconf_log(GCL_ERR, _("Unknown error registering gconfd with bonobo-activation; exiting\n"));
           break;
         }
       enter_shutdown ();
@@ -668,11 +668,11 @@
 
   gconfd_locale_cache_drop ();
 
   /* Now we can unregister with OAF, after everything is fixed up. */  
 
   if (server != CORBA_OBJECT_NIL)
     {
-      oaf_active_server_unregister ("", server);
+      bonobo_activation_active_server_unregister ("", server);
       server = CORBA_OBJECT_NIL;
     }
 
@@ -1658,9 +1658,8 @@
   
   CORBA_exception_init (&ev);
   
-  cl = CORBA_ORB_string_to_object (oaf_orb_get (),
-                                   (gchar*)ior,
-                                   &ev);
+  cl = CORBA_ORB_string_to_object (
+	  bonobo_activation_orb_get (), (gchar*)ior, &ev);
 
   CORBA_exception_free (&ev);
   
@@ -1707,9 +1706,8 @@
   
   CORBA_exception_init (&ev);
   
-  cl = CORBA_ORB_string_to_object (oaf_orb_get (),
-                                   lle->ior,
-                                   &ev);
+  cl = CORBA_ORB_string_to_object (
+	  bonobo_activation_orb_get (), lle->ior, &ev);
 
   CORBA_exception_free (&ev);
   
@@ -575,8 +575,8 @@
       g_assert (err);
       
-      /* Bad hack alert - register the current lockholder with oafd,
-       * since oafd seems to have forgotten about us.
+      /* Bad hack alert - register the current lockholder with bonobo-activation-server,
+       * since bonobo-activation-server seems to have forgotten about us.
        */
       gconf_log (GCL_WARNING, _("Failed to get lock for daemon: %s"),
@@ -668,11 +668,11 @@
   gconfd_locale_cache_drop ();
 
-  /* Now we can unregister with OAF, after everything is fixed up. */  
+  /* Now we can unregister with bonobo-activation everything is fixed up. */  
 
   if (server != CORBA_OBJECT_NIL)

-- 
 mmeeks gnu org  <><, Pseudo Engineer, itinerant idiot





[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]